====================================
Sphinx Plugin for Treemap Generation
====================================

Sphinx plugin that generates a treemap_ that visualizes the data of an input Cobertura_ XML file.

.. contents:: `Contents`
    :depth: 2
    :local:

.. toctree::
    :maxdepth: 2

    installation
    configuration
    usage

.. _treemap: https://en.wikipedia.org/wiki/Treemapping
.. _Cobertura: https://cobertura.github.io/cobertura/
.. _plotly: https://plotly.com/python/treemaps/
